<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\ThirdPlatform\Api;

use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Support\Traits\HttpClientHelpers;


class WuxiApiService
{
    use HttpClientHelpers;

    protected $platformInfo = null;

    public function __construct()
    {
        $this->platformInfo = app(ThirdApiPlatformRepository::class)->getPlatformInfoByPlatformName('wuxi_appTec');
        $this->platformInfo['platform_params'] = json_decode($this->platformInfo['platform_params'], true);
    }

    /**
     * 批量更新商品信息
     * @param $product
     * @return bool
     */
    public function pushBatchUpdateProduct($product){

        if(!$this->platformInfo){
            throw new \LogicException('第三方平台信息无法获取!',500);
        }

        try{

            $params = [];
            $params['chemicalProducts'] = $this->mergeApiMetaData($product);

            $response = $this->getPostClient('https://api.uploadcatalog.com/api/v1/update',$params, [
                $this->platformInfo['platform_params']['username'], $this->platformInfo['platform_params']['password']
            ]);

            return $this->apiResponse($response);
        }catch(\Exception $e){
            return $this->requestError($e);
        }
    }

    /**
     * 整理组装 api 数据
     * @param $metaData
     * @return array
     */
    public function mergeApiMetaData($metaData)
    {
        if(empty($metaData)){
           return [];
        }

        $mergeData = [];
        foreach($metaData['rawList'] as $datas){

            $tempData['supplier_product_id'] = $datas['r_code'];
            $tempData['mdl'] = '';
            $tempData['cas'] = $datas['c_cas'];
            $tempData['nu'] = '';
            $tempData['chinese_name'] = $datas['r_cn_name'];
            $tempData['english_name'] = $datas['r_en_name'];
            $tempData['chemicalformula'] = '';
            $tempData['purity'] = $datas['r_level'];
            /*$tempData['usually_ships_days_min'] = '';
            $tempData['usually_ships_within_days'] = '';
            $tempData['backorder_lead_time'] = '';*/
            $tempData['status'] = $datas['r_status'] == '1' ? 'ACTIVE' : 'INACTIVE';

            $tempData['inventorys'][] = [
                'type' => $datas['r_unit'],
                'quantity' => floatval($datas['r_stock']),
                'country' => 'CN',
                'stock_status' => $datas['r_stock'] > 0 ? 'INSTOCK' : 'OUTSTOCK',
            ];

            $tempData['package'] = [];

            if(isset($metaData['packageList'][$datas['r_code']])){
                $package = $metaData['packageList'][$datas['r_code']];
                $pack['unit_description'] = $package['p_pack_unit'];
                $pack['package_status'] = $package['p_status'] == '1' ? 'ACTIVE' : 'INACTIVE';
                $pack['inventorys'] = [
                    'package_quantity' => $package['p_stock'],
                    'stock_status' => $package['p_stock'] > 0 ? 'INSTOCK' : 'OUTSTOK',
                    'country' => 'CN'
                ];

                $pack['prices'] = [
                    'price' => $package['p_price'],
                    'currency' => 'RMB',
                    'status' => 'ACTIVE'
                ];

                $pack['costs'] = [
                    'In_cost' => $package['p_avg_cost'],
                    'In_cost_currency' => 'RMB',
                    'status' => $package['p_stock'] > 0 ? 'ACTIVE' : 'INACTVIE',
                ];

                $pack['wuxiPackagePricings'] = [
                    'discount'=> 0.00,
                    'currency' => 'RMB',
                    'status' => 'INACTIVE'
                ];

                array_push($tempData['package'],$pack);
            }

            array_push($mergeData,$tempData);
            unset($tempData);
        }

        return $mergeData;
    }

    protected function apiResponse($response)
    {
        $decodeResponse = json_decode($response,true);
        if($decodeResponse){
            if(!empty($decodeResponse['successProduct'])){
                return true;
            }

        }
        return false;
    }

    protected function requestError($response)
    {
       return false;
    }
}
